"""Core utilities module providing foundational helpers for the framework."""

from .require_extra import require_extra

__all__ = (
    "async",
    "chunking",
    "enums",
    "env",
    "exception",
    "file_folder",
    "hashing",
    "jsonable_encoder",
    "request",
    "require_extra",
    "retry",
    "safe_access",
    "singleton",
    "slug",
    "url",
    "validation",
)

require_extra("core", "requests")
